"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DownloaderNode = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const wa_decrypt_1 = require("@open-wa/wa-decrypt");
class DownloaderNode {
    constructor() {
        this.description = {
            displayName: 'WA Media Downloader Node',
            name: 'downloaderNode',
            group: ['transform'],
            version: 1,
            description: 'Downlaoder Node',
            defaults: {
                name: 'Downlaoder Node',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'URL',
                    name: 'url',
                    type: 'string',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
                {
                    displayName: 'Media Key',
                    name: 'mediaKey',
                    type: 'string',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
                {
                    displayName: 'File Hash',
                    name: 'filehash',
                    type: 'string',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
                {
                    displayName: 'Mime Type',
                    name: 'mimetype',
                    type: 'string',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
                {
                    displayName: 'Type',
                    name: 'type',
                    type: 'string',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
                {
                    displayName: 'Size',
                    name: 'size',
                    type: 'number',
                    default: '',
                    placeholder: 'Placeholder value',
                    description: 'The description text',
                },
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        let item;
        let mediaKey;
        let filehash;
        let mimetype;
        let type;
        let size;
        let url;
        let data;
        for (let itemIndex = 0; itemIndex < items.length; itemIndex++) {
            try {
                mediaKey = this.getNodeParameter('mediaKey', itemIndex, '');
                filehash = this.getNodeParameter('filehash', itemIndex, '');
                mimetype = this.getNodeParameter('mimetype', itemIndex, '');
                type = this.getNodeParameter('type', itemIndex, '');
                size = this.getNodeParameter('size', itemIndex, 0);
                url = this.getNodeParameter('url', itemIndex, '');
                data = await (0, wa_decrypt_1.decryptMedia)({
                    mediaKey: mediaKey,
                    filehash: filehash,
                    mimetype: mimetype,
                    type: type,
                    size: size,
                    deprecatedMms3Url: url
                });
                item = items[itemIndex];
                item.binary = {
                    key: {
                        data: Buffer.from(data).toString('base64'),
                        mimeType: mimetype,
                        fileSize: size.toString(),
                    }
                };
            }
            catch (error) {
                if (this.continueOnFail()) {
                    items.push({ json: this.getInputData(itemIndex)[0].json, error, pairedItem: itemIndex });
                }
                else {
                    if (error.context) {
                        error.context.itemIndex = itemIndex;
                        throw error;
                    }
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), error, {
                        itemIndex,
                    });
                }
            }
        }
        return this.prepareOutputData(items);
    }
}
exports.DownloaderNode = DownloaderNode;
//# sourceMappingURL=DownloaderNode.node.js.map